==> haskell-asn1-types-0.3.2-21-i686.pkg.tar.xz: usr/share/haskell/register/haskell-asn1-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: asn1-types
version: 0.3.2
id: asn1-types-0.3.2-61vI6GmIqV4BnqsxINTnsF
key: asn1-types-0.3.2-61vI6GmIqV4BnqsxINTnsF
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-asn1-types
synopsis: ASN.1 types
description:
    ASN.1 standard types
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Data.ASN1.BitArray Data.ASN1.OID Data.ASN1.Pretty Data.ASN1.Types
    Data.ASN1.Types.Lowlevel Data.ASN1.Types.String
abi: 67326da5b916cbf377ae50e7c9a8e9a5
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/asn1-types-0.3.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/asn1-types-0.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/asn1-types-0.3.2
hs-libraries: HSasn1-types-0.3.2-61vI6GmIqV4BnqsxINTnsF
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    hourglass-0.2.10-6vUY2VFiM1E873akQp7ZFT
    memory-0.14.6-HxsAJFqa809Bv6WJsrwqao
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             hourglass-0.2.10-6vUY2VFiM1E873akQp7ZFT=a7b4dc3a31dc3314e8c5a212498714d7
             memory-0.14.6-HxsAJFqa809Bv6WJsrwqao=cafe984b544153f4a07f0019238a8893
haddock-interfaces: /usr/share/doc/haskell-asn1-types/html/asn1-types.haddock
haddock-html: /usr/share/doc/haskell-asn1-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-asn1-types-0.3.2-22-i686.pkg.tar.xz: usr/share/haskell/register/haskell-asn1-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: asn1-types
version: 0.3.2
id: asn1-types-0.3.2-6FWfZSA3HIO38kSged65K
key: asn1-types-0.3.2-6FWfZSA3HIO38kSged65K
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-asn1-types
synopsis: ASN.1 types
description:
    ASN.1 standard types
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Data.ASN1.BitArray Data.ASN1.OID Data.ASN1.Pretty Data.ASN1.Types
    Data.ASN1.Types.Lowlevel Data.ASN1.Types.String
abi: b4f5e088373709016ff3a955fe63a5a2
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/asn1-types-0.3.2
library-dirs: /usr/lib/ghc-8.2.1/site-local/asn1-types-0.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/asn1-types-0.3.2
hs-libraries: HSasn1-types-0.3.2-6FWfZSA3HIO38kSged65K
depends:
    base-4.10.0.0 bytestring-0.10.8.2
    hourglass-0.2.10-6vUY2VFiM1E873akQp7ZFT
    memory-0.14.7-CZTdOBCJoah1c0c3vYdFwT
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             hourglass-0.2.10-6vUY2VFiM1E873akQp7ZFT=a7b4dc3a31dc3314e8c5a212498714d7
             memory-0.14.7-CZTdOBCJoah1c0c3vYdFwT=db3ff9fa1505f44a985d28fbfc88363e
haddock-interfaces: /usr/share/doc/haskell-asn1-types/html/asn1-types.haddock
haddock-html: /usr/share/doc/haskell-asn1-types/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
